//
//  AppDelegate.m
//  APNSDemo
//
//  Created by Mobisoft on 12/9/14.
//  Copyright (c) 2014 MIPI. All rights reserved.
//

#import "AppDelegate.h"

NSString * const appId = @"Parse key paste here, App Id";
NSString * const clientKey = @"Parse key paste here, Client Key";

NSString * const notificationCategoryIdentifier  = @"Friend_Request";
NSString * const notificationActionOneIdentifier = @"Accept_Action";
NSString * const notificationActionTwoIdentifier = @"Reject_Action";

// Extra Action for model Alert
NSString * const notificationActionThreeIdentifier = @"Action_3";
NSString * const notificationActionFourIdentifier = @"Action_4";




@interface AppDelegate ()

@end

@implementation AppDelegate


- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {
    // Override point for customization after application launch.
    
    self.window = [[UIWindow alloc] initWithFrame:[UIScreen mainScreen].bounds];
    
    self.rootViewController = [[RootViewController alloc]init];
    
    self.window.rootViewController = self.rootViewController;
    
    [self.window makeKeyAndVisible];
    
    [self setupParseKey];
    
    [self registerForAPNS];
    
    return YES;
    
}

- (void)applicationWillResignActive:(UIApplication *)application {
    // Sent when the application is about to move from active to inactive state. This can occur for certain types of temporary interruptions (such as an incoming phone call or SMS message) or when the user quits the application and it begins the transition to the background state.
    // Use this method to pause ongoing tasks, disable timers, and throttle down OpenGL ES frame rates. Games should use this method to pause the game.
}

- (void)applicationDidEnterBackground:(UIApplication *)application {
    // Use this method to release shared resources, save user data, invalidate timers, and store enough application state information to restore your application to its current state in case it is terminated later.
    // If your application supports background execution, this method is called instead of applicationWillTerminate: when the user quits.
}

- (void)applicationWillEnterForeground:(UIApplication *)application {
    // Called as part of the transition from the background to the inactive state; here you can undo many of the changes made on entering the background.
}

- (void)applicationDidBecomeActive:(UIApplication *)application {
    // Restart any tasks that were paused (or not yet started) while the application was inactive. If the application was previously in the background, optionally refresh the user interface.
}

- (void)applicationWillTerminate:(UIApplication *)application {
    // Called when the application is about to terminate. Save data if appropriate. See also applicationDidEnterBackground:.
}


#pragma mark - Parse Setup -


- (void)setupParseKey {
    
    [Parse setApplicationId:appId clientKey:clientKey];
    
}


#pragma mark - Push Notification Setup -

- (void)registerForAPNS {
    
    if ([[[UIDevice currentDevice] systemVersion] floatValue] >= 8.0)
    {
        
        UIMutableUserNotificationAction *acceptAction = [[UIMutableUserNotificationAction alloc] init];
        [acceptAction setActivationMode:UIUserNotificationActivationModeBackground];
        [acceptAction setTitle:@"Accept"];
        [acceptAction setIdentifier:notificationActionOneIdentifier];
        [acceptAction setDestructive:YES];
        [acceptAction setAuthenticationRequired:NO];
        
        UIMutableUserNotificationAction *rejectAction = [[UIMutableUserNotificationAction alloc] init];
        [rejectAction setActivationMode:UIUserNotificationActivationModeBackground];
        [rejectAction setTitle:@"Reject"];
        [rejectAction setIdentifier:notificationActionTwoIdentifier];
        [rejectAction setDestructive:NO];
        [rejectAction setAuthenticationRequired:NO];
        
        
        // Extra action for model Alert.
        UIMutableUserNotificationAction *rejectAction3 = [[UIMutableUserNotificationAction alloc] init];
        [rejectAction3 setActivationMode:UIUserNotificationActivationModeBackground];
        [rejectAction3 setTitle:@"Action 3"];
        [rejectAction3 setIdentifier:notificationActionThreeIdentifier];
        [rejectAction3 setDestructive:NO];
        [rejectAction3 setAuthenticationRequired:NO];

        
        UIMutableUserNotificationAction *rejectAction4 = [[UIMutableUserNotificationAction alloc] init];
        [rejectAction4 setActivationMode:UIUserNotificationActivationModeBackground];
        [rejectAction4 setTitle:@"Action 4"];
        [rejectAction4 setIdentifier:notificationActionFourIdentifier];
        [rejectAction4 setDestructive:NO];
        [rejectAction4 setAuthenticationRequired:NO];
        
        
        UIMutableUserNotificationCategory *actionCategory;
        actionCategory = [[UIMutableUserNotificationCategory alloc] init];
        [actionCategory setIdentifier:notificationCategoryIdentifier];
        
        [actionCategory setActions:@[acceptAction, rejectAction]
                        forContext:UIUserNotificationActionContextMinimal];
        
        [actionCategory setActions:@[acceptAction, rejectAction,rejectAction3,rejectAction4]
                        forContext:UIUserNotificationActionContextDefault];

        
        NSSet *notificationCategories = [NSSet setWithObject:actionCategory];
        UIUserNotificationType notificationTypes = (UIUserNotificationTypeAlert|
                                                    UIUserNotificationTypeSound|
                                                    UIUserNotificationTypeBadge);
        
        UIUserNotificationSettings *settings;
        settings = [UIUserNotificationSettings settingsForTypes:notificationTypes
                                                     categories:notificationCategories];
        
        [[UIApplication sharedApplication] registerUserNotificationSettings:settings];
        
        [[UIApplication sharedApplication] registerForRemoteNotifications];
        
    } else {
        
        [[UIApplication sharedApplication] registerForRemoteNotificationTypes:UIRemoteNotificationTypeAlert|UIRemoteNotificationTypeBadge|UIRemoteNotificationTypeSound];
    }
    
}


- (void)application:(UIApplication *)application didRegisterForRemoteNotificationsWithDeviceToken:(NSData *)deviceToken {
    
    NSLog(@"Register For RemoteNotifications With DeviceToken");
    
    PFInstallation *currentInstallation = [PFInstallation currentInstallation];
    [currentInstallation setDeviceTokenFromData:deviceToken];
    currentInstallation.channels = @[@"global"];
    
    [currentInstallation saveInBackground];
    
    
}

- (void)application:(UIApplication *)application didFailToRegisterForRemoteNotificationsWithError:(NSError *)error {
    
    
    if (error.code == 3010) {
        
        NSLog(@"Push notifications are not supported in the iOS Simulator.");
        
    } else {
        
        // show some alert or otherwise handle the failure to register.
        NSLog(@"application:didFailToRegisterForRemoteNotificationsWithError: %@", error);
        
    }
}


 - (void)application:(UIApplication *)application didReceiveRemoteNotification:(NSDictionary *)userInfo {
 
     NSLog(@"didReceiveRemoteNotification **************");

 }


- (void)application:(UIApplication *)application didReceiveRemoteNotification:(NSDictionary *)userInfo fetchCompletionHandler:(void (^)(UIBackgroundFetchResult result))completionHandler NS_AVAILABLE_IOS(7_0) {
    
    NSLog(@"didReceiveRemoteNotification");
    
    if([userInfo[@"aps"][@"content-available"] intValue]== 1) // silent notification
    {
        NSLog (@"slient notification received");
        
        completionHandler(UIBackgroundFetchResultNewData);
        
        
    } else  {
        
        completionHandler(UIBackgroundFetchResultNoData);

        
        UIAlertView *alert = [[UIAlertView alloc]
                              initWithTitle:@"Info"
                              message:@"Received Push notification."
                              delegate:self cancelButtonTitle:@"Ok"
                              otherButtonTitles:nil];
        
        [alert show];
        
        
    }
    
    return;
    
}



- (void)application:(UIApplication *)application handleActionWithIdentifier:(NSString *)identifier forRemoteNotification:(NSDictionary *)userInfo completionHandler:(void (^)())completionHandler {
    
    NSLog(@"handleActionWithIdentifier");
    
    NSLog(@"handleActionWithIdentifier %@",identifier);
    
    if ([identifier isEqualToString:notificationActionOneIdentifier]) {
        
        NSLog(@"Friend request accepted.");
        
    }
    else if ([identifier isEqualToString:notificationActionTwoIdentifier]) {
        
        NSLog(@"Friend request rejected.");
        
    }
    
    if (completionHandler) {
        
        completionHandler();
    }
    
    
}





@end
